<?php


$rcpb_forum_meta_box = array(
	'id' => 'rcpb_forum_meta_box',
	'title' => __( 'Restrict this Forum', 'rcp_bbpress' ),
	'context' => 'side',
	'priority' => 'core',
	'fields' => array(
		array(
			'name' => __( 'Paid Only?', 'rcp_bbpress' ),
			'id' => '_is_forum_paid',
			'type' => 'checkbox',
			'desc' => __( 'Restrict this forum to paid users only', 'rcp_bbpress' )
		)
	)
);
$rcpb_topic_meta_box = array(
	'id' => 'rcpb_topic_meta_box',
	'title' => __( 'Restrict this Topic', 'rcp_bbpress' ),
	'context' => 'side',
	'priority' => 'core',
	'fields' => array(
		array(
			'name' => __( 'Paid Only?', 'rcp_bbpress' ),
			'id' => '_is_topic_paid',
			'type' => 'checkbox',
			'desc' => __( 'Restrict this topic to paid users only', 'rcp_bbpress' )
		)
	)
);

// Add meta box


function rcp_bbp_add_meta_boxes() {
	global $rcpb_forum_meta_box, $rcpb_topic_meta_box;
	add_meta_box( $rcpb_forum_meta_box['id'], $rcpb_forum_meta_box['title'], 'rcp_bbp_render_meta_box', 'forum', $rcpb_forum_meta_box['context'], $rcpb_forum_meta_box['priority'] );
	add_meta_box( $rcpb_topic_meta_box['id'], $rcpb_topic_meta_box['title'], 'rcp_bbp_render_meta_box', 'topic', $rcpb_topic_meta_box['context'], $rcpb_topic_meta_box['priority'] );

}
add_action( 'admin_menu', 'rcp_bbp_add_meta_boxes' );

// Callback function to show fields in meta box
function rcp_bbp_render_meta_box() {
	global $rcpb_forum_meta_box, $rcpb_topic_meta_box, $post;

	// Use nonce for verification
	echo '<input type="hidden" name="rcpb_meta_box" value="', wp_create_nonce( basename( __FILE__ ) ), '" />';

	echo '<table class="form-table">';

	if ( $post->post_type == 'forum' ) {
		foreach ( $rcpb_forum_meta_box['fields'] as $field ) {
			// get current post meta data
			$meta = get_post_meta( $post->ID, $field['id'], true );

			echo '<tr>',
			'<th style="width:20%"><label for="', $field['id'], '">', $field['name'], '</label></th>',
			'<td>';
			switch ( $field['type'] ) {
			case 'checkbox':
				echo '<input type="checkbox" value="1" name="', $field['id'], '" id="', $field['id'], '"', $meta ? ' checked="checked"' : '', ' />';
				break;
			}
			echo     '<td>', $field['desc'], '</td><td>',
			'</tr>';
		}
	} else {
		foreach ( $rcpb_topic_meta_box['fields'] as $field ) {
			// get current post meta data
			$meta = get_post_meta( $post->ID, $field['id'], true );

			echo '<tr>',
			'<th style="width:20%"><label for="', $field['id'], '">', $field['name'], '</label></th>',
			'<td>';
			switch ( $field['type'] ) {
			case 'checkbox':
				echo '<input type="checkbox" value="1" name="', $field['id'], '" id="', $field['id'], '"', $meta ? ' checked="checked"' : '', ' />';
				break;
			}
			echo     '<td>', $field['desc'], '</td><td>',
			'</tr>';
		}
	}
	echo '</table>';
}

// Save data from meta box
function rcp_bbp_save_meta_data( $post_id ) {
	global $rcpb_forum_meta_box, $rcpb_topic_meta_box;

	// verify nonce
	if ( !isset( $_POST['rcpb_meta_box'] ) || !wp_verify_nonce( $_POST['rcpb_meta_box'], basename( __FILE__ ) ) ) {
		return $post_id;
	}

	// check autosave
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return $post_id;
	}

	// check permissions
	if ( 'page' == $_POST['post_type'] ) {
		if ( !current_user_can( 'edit_page', $post_id ) ) {
			return $post_id;
		}
	} elseif ( !current_user_can( 'edit_post', $post_id ) ) {
		return $post_id;
	}

	foreach ( $rcpb_forum_meta_box['fields'] as $field ) {
		if ( isset( $_POST[$field['id']] ) ) {

			$old = get_post_meta( $post_id, $field['id'], true );
			$data = $_POST[$field['id']];

			if ( ( $data || $data == 0 ) && $data != $old ) {
				update_post_meta( $post_id, $field['id'], $data );
			} elseif ( '' == $data && $old ) {
				delete_post_meta( $post_id, $field['id'], $old );
			}
		} else {
			delete_post_meta( $post_id, $field['id'] );
		}
	}
	foreach ( $rcpb_topic_meta_box['fields'] as $field ) {
		if ( isset( $_POST[$field['id']] ) ) {

			$old = get_post_meta( $post_id, $field['id'], true );
			$data = $_POST[$field['id']];

			if ( ( $data || $data == 0 ) && $data != $old ) {
				update_post_meta( $post_id, $field['id'], $data );
			} elseif ( '' == $data && $old ) {
				delete_post_meta( $post_id, $field['id'], $old );
			}
		} else {
			delete_post_meta( $post_id, $field['id'] );
		}
	}
}
add_action( 'save_post', 'rcp_bbp_save_meta_data' );
